# readimc

<a href="#"><img alt="Python" src="https://img.shields.io/pypi/pyversions/readimc" /></a>
<a href="https://github.com/BodenmillerGroup/readimc/actions/workflows/build.yml" alt="Build"><img alt="Build" src="https://img.shields.io/github/workflow/status/BodenmillerGroup/readimc/build?label=build" /></a>
<a href="https://pypi.org/project/readimc" alt="PyPI"><img alt="PyPI" src="https://img.shields.io/pypi/v/readimc" /></a>
<a href="#"><img alt="Coverage" src="https://img.shields.io/codecov/c/github/BodenmillerGroup/readimc" /></a>
<a href="https://bodenmillergroup.github.io/readimc" alt="Documentation"><img alt="Documentation" src="https://img.shields.io/github/workflow/status/BodenmillerGroup/readimc/docs?label=docs" /></a>
<a href="https://github.com/BodenmillerGroup/readimc/issues" alt="Issues"><img alt="Issues" src="https://img.shields.io/github/issues/BodenmillerGroup/readimc" /></a>
<a href="https://github.com/BodenmillerGroup/readimc/pulls" alt="Pull requests"><img alt="Pull requests" src="https://img.shields.io/github/issues-pr/BodenmillerGroup/readimc" /></a>
<a href="https://github.com/BodenmillerGroup/readimc/blob/main/LICENSE" alt="License"><img alt="License" src="https://img.shields.io/github/license/BodenmillerGroup/readimc" /></a>

Python package for reading Fluidigm&reg; Imaging Mass Cytometry&trade; files

Documentation is available at https://bodenmillergroup.github.io/readimc
